@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCERECURRENCE_H
-#define INCIDENCEEDITOR_INCIDENCERECURRENCE_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 
@@ -121,4 +120,3 @@ private:
 };
 }
 
-#endif
